IntegrationTest class

Constructors

IntegrationTest({required TesterFactory testerFactory, required IntegrationTestConfig config})

Properties

config IntegrationTestConfig
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start<T extends Widget>({required WidgetTester tester, required Future<T> mainWidget(), Future<void> setupPreWidgetCreated()?, Future<void> setupPrePumpedWidget()?}) Future<ITester>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required TesterFactory testerFactory, required IntegrationTestConfig config}) → dynamic