method_channels/base_method_channel_mock library

Classes

BaseMethodChannelMock
Base class for method channel mocks that provides common functionality and standardizes the way we create method channel mocks.