IntegrationTestHttpResponse class

Constructors

IntegrationTestHttpResponse({required String path, int statusCode = 200, Map<String, dynamic>? headers, dynamic body, bool ignoreQuery = false, Duration? delay, HttpMethod? method})
const

Properties

body → dynamic
final
delay Duration?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>?
final
ignoreQuery bool
final
method HttpMethod?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withOverrides({String? pathOverride, dynamic bodyMerge, dynamic bodyOverrides, int? statusCodeOverride, bool ignoreQuery = false, Duration? delayOverride, HttpMethod? methodOverride}) IntegrationTestHttpResponse
Creates a new response by overriding specific fields of an existing response.

Operators

operator ==(Object other) bool
The equality operator.
inherited