FlutterTestNativeConfig class

Common configuration for FlutterTestNativeImpl

Constructors

FlutterTestNativeConfig({Duration existsTimeout = const Duration(seconds: 10), Duration visibleTimeout = const Duration(seconds: 10), Duration settleTimeout = const Duration(seconds: 10), SettlePolicy settlePolicy = SettlePolicy.noSettle, Duration dragDuration = const Duration(milliseconds: 100), Duration settleBetweenScrollsTimeout = const Duration(seconds: 5)})
Creates a new FlutterTestNativeConfig
const

Properties

dragDuration Duration
Time that it takes to perform drag gesture in scrolling methods
final
existsTimeout Duration
Time after which FlutterTestNativeImpl.waitUntilExists fails if it doesn't find an existing widget.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settleBetweenScrollsTimeout Duration
Timeout used to settle in between drag gestures in scrolling methods
final
settlePolicy → SettlePolicy
Defines which pump method should be called after actions
final
settleTimeout Duration
Time after which FlutterTestNativeImpl.pumpAndSettle fails.
final
visibleTimeout Duration
Time after which FlutterTestNativeImpl.waitUntilVisible fails if it doesn't find a visible widget.
final

Methods

copyWith({Duration? existsTimeout, Duration? visibleTimeout, Duration? settleTimeout, SettlePolicy? settlePolicy, Duration? dragDuration, Duration? settleBetweenScrollsTimeout}) FlutterTestNativeConfig
Creates a copy of this config but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited