settleBetweenScrollsTimeout property
Timeout used to settle in between drag gestures in scrolling methods
Implementation
final Duration settleBetweenScrollsTimeout;
Timeout used to settle in between drag gestures in scrolling methods
final Duration settleBetweenScrollsTimeout;