ITester class abstract

Implementers

Constructors

ITester()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tester WidgetTester
no setter

Methods

call(dynamic finder) Finder
enterText(Finder finder, String text, {SettlePolicy? settlePolicy, Duration? visibleTimeout, Duration? settleTimeout}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pump([Duration? duration, EnginePhase phase = EnginePhase.sendSemanticsUpdate]) Future<void>
pumpAndSettle({Duration duration = const Duration(milliseconds: 100), Duration? timeout}) Future<void>
pumpAndTrySettle({Duration duration = const Duration(milliseconds: 100), Duration? timeout, EnginePhase? phase = EnginePhase.sendSemanticsUpdate}) Future<void>
pumpFor(Duration duration, {Duration step}) Future<void>
Pumps for a total duration, advancing time in steps.
pumpWidgetAndSettle(Widget widget, {Duration? duration, EnginePhase phase = EnginePhase.sendSemanticsUpdate, Duration? timeout}) Future<void>
scrollUntilVisible({required Finder matcher, AxisDirection? direction, SettlePolicy? settlePolicy}) Future<Finder>
tap(Finder finder, {SettlePolicy? settlePolicy, Duration? visibleTimeout, Duration? settleTimeout}) Future<void>
toString() String
A string representation of this object.
inherited
waitUntilVisible(Finder finder, {Duration? timeout, Alignment alignment = Alignment.center, Duration? settleDuration}) Future<Finder>

Operators

operator ==(Object other) bool
The equality operator.
inherited