IntegrationTestHttpOverrides class
- Inheritance
-
- Object
- HttpOverrides
- IntegrationTestHttpOverrides
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
permanentResponses
→ Map<
String, IntegrationTestHttpResponse> -
no setter
-
requests
→ List<
RequestVerification> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addResponse(
IntegrationTestHttpResponse response) → void -
addResponses(
List< IntegrationTestHttpResponse> responses) → void -
clearAll(
) → void -
clearPermanentResponses(
) → void -
clearQueuedResponses(
) → void -
clearRequests(
) → void -
createHttpClient(
SecurityContext? context) → HttpClient -
Returns a new HttpClient using the given
context.override -
findAllRequests(
String path, {HttpMethod? method}) → List< RequestVerification> -
findProxyFromEnvironment(
Uri url, Map< String, String> ? environment) → String -
Resolves the proxy server to be used for HTTP connections.
inherited
-
findRequest(
String path, {HttpMethod? method}) → RequestVerification? -
getMapKey(
String path, bool ignoreQuery, HttpMethod? method) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onFakeRequest(
dynamic request, dynamic client) → FutureOr< FakeHttpResponse> -
queueResponse(
IntegrationTestHttpResponse response) → void -
replaceResponse(
IntegrationTestHttpResponse response) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited